.. _Installation: installation.html
.. _FSL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/
.. _`Docker installation`: https://docs.docker.com/install/
.. _`Docker Hub`: https://hub.docker.com/r/poldracklab/fmriprep/tags
.. _Singularity: https://github.com/singularityware/singularity
.. _TACC: https://www.tacc.utexas.edu/
.. _BIDS-validator: https://github.com/bids-standard/bids-validator
